@@ -1,11 +1,10 @@
 /*
-  SPDX-FileCopyrightText: 2015-2021 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2015-2022 Laurent Montel <montel@kde.org>
 
   SPDX-License-Identifier: GPL-2.0-only
 */
 
-#ifndef FILTERACTIONADDTOADDRESSBOOKTEST_H
-#define FILTERACTIONADDTOADDRESSBOOKTEST_H
+#pragma once
 
 #include <QObject>
 
@@ -14,7 +13,7 @@ class FilterActionAddToAddressBookTest : public QObject
     Q_OBJECT
 public:
     explicit FilterActionAddToAddressBookTest(QObject *parent = nullptr);
-    ~FilterActionAddToAddressBookTest();
+    ~FilterActionAddToAddressBookTest() override;
 private Q_SLOTS:
     void shouldHaveDefaultValue();
     void shouldReportErrorWhenArgumentIsEmpty();
@@ -22,4 +21,3 @@ private Q_SLOTS:
     void shouldRequiresPart();
 };
 
-#endif // FILTERACTIONADDTOADDRESSBOOKTEST_H
