@@ -1,21 +1,19 @@
 /*
-  SPDX-FileCopyrightText: 2015-2020 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2015-2022 Laurent Montel <montel@kde.org>
 
   SPDX-License-Identifier: GPL-2.0-only
 */
 
 #include "filteractiondeletetest.h"
 #include "../filteractions/filteractiondelete.h"
-#include <QTest>
 #include <QLabel>
+#include <QTest>
 FilterActionDeleteTest::FilterActionDeleteTest(QObject *parent)
     : QObject(parent)
 {
 }
 
-FilterActionDeleteTest::~FilterActionDeleteTest()
-{
-}
+FilterActionDeleteTest::~FilterActionDeleteTest() = default;
 
 void FilterActionDeleteTest::shouldHaveDefaultValue()
 {
