@@ -1,11 +1,10 @@
 /*
-  SPDX-FileCopyrightText: 2015-2021 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2015-2022 Laurent Montel <montel@kde.org>
 
   SPDX-License-Identifier: GPL-2.0-only
 */
 
-#ifndef FILTERACTIONSETSTATUSTEST_H
-#define FILTERACTIONSETSTATUSTEST_H
+#pragma once
 
 #include <QObject>
 
@@ -14,7 +13,7 @@ class FilterActionSetStatusTest : public QObject
     Q_OBJECT
 public:
     explicit FilterActionSetStatusTest(QObject *parent = nullptr);
-    ~FilterActionSetStatusTest();
+    ~FilterActionSetStatusTest() override;
 private Q_SLOTS:
     void shouldHaveDefaultValue();
     void shouldHaveSieveRequires();
@@ -22,4 +21,3 @@ private Q_SLOTS:
     void shouldRequiresPart();
 };
 
-#endif // FILTERACTIONSETSTATUSTEST_H
