@@ -1,11 +1,10 @@
 /*
-  SPDX-FileCopyrightText: 2015-2021 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2015-2022 Laurent Montel <montel@kde.org>
 
   SPDX-License-Identifier: GPL-2.0-only
 */
 
-#ifndef MAILFILTERTEST_H
-#define MAILFILTERTEST_H
+#pragma once
 
 #include <QObject>
 
@@ -14,10 +13,9 @@ class MailFilterTest : public QObject
     Q_OBJECT
 public:
     explicit MailFilterTest(QObject *parent = nullptr);
-    ~MailFilterTest();
+    ~MailFilterTest() override;
 private Q_SLOTS:
     void shouldHaveDefaultValue();
     void shouldApplySettings();
 };
 
-#endif // MAILFILTERTEST_H
