@@ -1,11 +1,10 @@
 /*
-   SPDX-FileCopyrightText: 2016-2021 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2016-2022 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
-#ifndef FILTERACTIONMISSINGTAGDIALOG_H
-#define FILTERACTIONMISSINGTAGDIALOG_H
+#pragma once
 
 #include <QDialog>
 class QListWidget;
@@ -19,7 +18,7 @@ public:
                                           const QString &filtername,
                                           const QString &argsStr,
                                           QWidget *parent = nullptr);
-    ~FilterActionMissingTagDialog();
+    ~FilterActionMissingTagDialog() override;
     Q_REQUIRED_RESULT QString selectedTag() const;
 
 private:
@@ -31,4 +30,3 @@ private:
     QListWidget *mTagList = nullptr;
 };
 }
-#endif // FILTERACTIONMISSINGTAGDIALOG_H
