@@ -1,6 +1,6 @@
 /*
 
-  SPDX-FileCopyrightText: 2012-2021 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2012-2022 Laurent Montel <montel@kde.org>
 
   SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -84,7 +84,7 @@ QString FilterActionStatus::argsAsString() const
 {
     const int index = mParameterList.indexOf(mParameter);
     if (index < 1) {
-        return QString();
+        return {};
     }
 
     return realStatusString(FilterActionStatus::stati[index - 1].statusStr());
