@@ -5,8 +5,7 @@
  *
  */
 
-#ifndef MAILCOMMON_FILTERACTIONWITHURL_H
-#define MAILCOMMON_FILTERACTIONWITHURL_H
+#pragma once
 
 #include "filteraction.h"
 #include <QToolButton>
@@ -38,7 +37,7 @@ class FilterActionWithUrlHelpButton : public QToolButton
     Q_OBJECT
 public:
     explicit FilterActionWithUrlHelpButton(QWidget *parent = nullptr);
-    ~FilterActionWithUrlHelpButton();
+    ~FilterActionWithUrlHelpButton() override;
 };
 
 class FilterActionWithUrl : public FilterAction
@@ -105,4 +104,3 @@ private Q_SLOTS:
 };
 }
 
-#endif
