@@ -1,17 +1,18 @@
 /*
-   SPDX-FileCopyrightText: 2018-2021 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2018-2022 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
-#ifndef FILTERCONVERTTOSIEVEPURPOSEMENUWIDGET_H
-#define FILTERCONVERTTOSIEVEPURPOSEMENUWIDGET_H
+#pragma once
 
 #include <PimCommon/PurposeMenuWidget>
 namespace KPIMTextEdit
 {
 class PlainTextEditor;
 }
+namespace MailCommon
+{
 class FilterconverttosievePurposeMenuWidget : public PimCommon::PurposeMenuWidget
 {
     Q_OBJECT
@@ -19,11 +20,10 @@ public:
     explicit FilterconverttosievePurposeMenuWidget(QWidget *parentWidget, QObject *parent = nullptr);
     ~FilterconverttosievePurposeMenuWidget() override;
 
-    QByteArray text() override;
+    Q_REQUIRED_RESULT QByteArray text() override;
     void setEditorWidget(KPIMTextEdit::PlainTextEditor *editor);
 
 private:
     KPIMTextEdit::PlainTextEditor *mEditor = nullptr;
 };
-
-#endif // FILTERCONVERTTOSIEVEPURPOSEMENUWIDGET_H
+}
