@@ -1,13 +1,13 @@
 /*
-  SPDX-FileCopyrightText: 2015-2021 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2015-2022 Laurent Montel <montel@kde.org>
 
   SPDX-License-Identifier: GPL-2.0-only
 */
 #include "filterimportergmailtest.h"
 #include "filter/mailfilter.h"
 #include "filtertestkernel.h"
-#include <AkonadiCore/qtest_akonadi.h>
 #include <MailCommon/MailKernel>
+#include <akonadi/qtest_akonadi.h>
 
 FilterImporterGmailTest::FilterImporterGmailTest(QObject *parent)
     : QObject(parent)
