@@ -1,10 +1,9 @@
 /*
-  SPDX-FileCopyrightText: 2013-2021 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2013-2022 Laurent Montel <montel@kde.org>
 
   SPDX-License-Identifier: GPL-2.0-only
 */
-#ifndef FILTERTESTKERNEL_H
-#define FILTERTESTKERNEL_H
+#pragma once
 
 #include <MailCommon/MailInterfaces>
 
@@ -51,4 +50,3 @@ private:
     Akonadi::EntityMimeTypeFilterModel *mCollectionModel = nullptr;
 };
 
-#endif
