@@ -1,5 +1,5 @@
 /*
-  SPDX-FileCopyrightText: 2012-2021 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2012-2022 Laurent Montel <montel@kde.org>
 
   SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -30,9 +30,7 @@ FilterImporterBalsa::FilterImporterBalsa()
 {
 }
 
-FilterImporterBalsa::~FilterImporterBalsa()
-{
-}
+FilterImporterBalsa::~FilterImporterBalsa() = default;
 
 QString FilterImporterBalsa::defaultFiltersSettingsPath()
 {
@@ -87,7 +85,7 @@ void FilterImporterBalsa::parseCondition(const QString &condition, MailCommon::M
         // no multi condition
         conditionList << condition;
     }
-    for (QString cond : qAsConst(conditionList)) {
+    for (QString cond : std::as_const(conditionList)) {
         cond = cond.trimmed();
         if (cond.startsWith(QLatin1String("NOT"))) {
             cond = cond.right(cond.length() - 3);
