@@ -1,11 +1,10 @@
 /*
-  SPDX-FileCopyrightText: 2012-2020 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2012-2022 Laurent Montel <montel@kde.org>
 
   SPDX-License-Identifier: GPL-2.0-or-later
 */
 
-#ifndef MAILCOMMON_FILTERIMPORTER_FILTERIMPORTERBALSA_P_H
-#define MAILCOMMON_FILTERIMPORTER_FILTERIMPORTERBALSA_P_H
+#pragma once
 
 #include "filterimporterabstract.h"
 
@@ -13,7 +12,8 @@ class QFile;
 class KConfigGroup;
 class KConfig;
 
-namespace MailCommon {
+namespace MailCommon
+{
 class MailFilter;
 
 class FilterImporterBalsa : public FilterImporterAbstract
@@ -24,6 +24,7 @@ public:
     ~FilterImporterBalsa();
     static QString defaultFiltersSettingsPath();
     void readConfig(KConfig *config);
+
 private:
     void parseFilter(const KConfigGroup &grp);
     void parseCondition(const QString &condition, MailCommon::MailFilter *filter);
@@ -31,4 +32,3 @@ private:
 };
 }
 
-#endif // FILTERIMPORTERBALSA_H
