@@ -1,5 +1,5 @@
 /*
-  SPDX-FileCopyrightText: 2012-2020 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2012-2022 Laurent Montel <montel@kde.org>
 
   SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -9,8 +9,8 @@
 #include "filter/mailfilter.h"
 #include "mailcommon_debug.h"
 
-#include <QFile>
 #include <QDir>
+#include <QFile>
 
 using namespace MailCommon;
 
@@ -33,9 +33,7 @@ FilterImporterClawsMails::FilterImporterClawsMails(bool interactive)
 {
 }
 
-FilterImporterClawsMails::~FilterImporterClawsMails()
-{
-}
+FilterImporterClawsMails::~FilterImporterClawsMails() = default;
 
 void FilterImporterClawsMails::readStream(QTextStream &stream)
 {
@@ -45,9 +43,9 @@ void FilterImporterClawsMails::readStream(QTextStream &stream)
         qCDebug(MAILCOMMON_LOG) << " line :" << line << " filter " << filter;
 
         if (line.isEmpty()) {
-            //Nothing
+            // Nothing
         } else if (line.startsWith(QLatin1Char('[')) && line.endsWith(QLatin1Char(']'))) {
-            //TODO
+            // TODO
         } else {
             appendFilter(filter);
             filter = parseLine(line);
@@ -63,15 +61,15 @@ QString FilterImporterClawsMails::defaultFiltersSettingsPath()
 
 MailFilter *FilterImporterClawsMails::parseLine(const QString &line)
 {
-    auto *filter = new MailFilter();
+    auto filter = new MailFilter();
     QString tmp = line;
-    //Enabled ?
+    // Enabled ?
     if (tmp.startsWith(QLatin1String("enabled"))) {
         filter->setEnabled(true);
         tmp.remove(QStringLiteral("enabled "));
     }
 
-    //Filter name
+    // Filter name
     if (tmp.startsWith(QLatin1String("rulename"))) {
         tmp.remove(QStringLiteral("rulename "));
         int pos;
@@ -79,34 +77,34 @@ MailFilter *FilterImporterClawsMails::parseLine(const QString &line)
         filter->pattern()->setName(name);
         filter->setToolbarName(name);
 
-        tmp = tmp.mid(pos + 2); //remove "\" "
+        tmp = tmp.mid(pos + 2); // remove "\" "
         qCDebug(MAILCOMMON_LOG) << " new tmp" << tmp;
     }
 
     tmp = extractConditions(tmp, filter);
 
     tmp = extractActions(tmp, filter);
-    //TODO
+    // TODO
     return filter;
 }
 
 QString FilterImporterClawsMails::extractActions(const QString &line, MailFilter *filter)
 {
-    Q_UNUSED(filter);
+    Q_UNUSED(filter)
     return line;
 }
 
 QString FilterImporterClawsMails::extractConditions(const QString &line, MailFilter *filter)
 {
     QByteArray fieldName;
-    //Action
+    // Action
     if (line.startsWith(QLatin1String("subject"))) {
         fieldName = "subject";
     } else if (line.startsWith(QLatin1String("age_lower"))) {
     }
     filter->pattern()->setOp(SearchPattern::OpAnd);
-    //TODO
-    return QString();
+    // TODO
+    return {};
 }
 
 QString FilterImporterClawsMails::extractString(const QString &tmp, int &pos)
