@@ -1,11 +1,10 @@
 /*
-  SPDX-FileCopyrightText: 2013-2021 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2013-2022 Laurent Montel <montel@kde.org>
 
   SPDX-License-Identifier: GPL-2.0-or-later
 */
 
-#ifndef MAILCOMMON_FILTERSELECTIONDIALOG_H
-#define MAILCOMMON_FILTERSELECTIONDIALOG_H
+#pragma once
 
 #include <QDialog>
 
@@ -28,7 +27,7 @@ public:
     explicit FilterSelectionDialog(QWidget *parent = nullptr);
     ~FilterSelectionDialog() override;
     void setFilters(const QVector<MailFilter *> &filters);
-    QVector<MailFilter *> selectedFilters() const;
+    Q_REQUIRED_RESULT QVector<MailFilter *> selectedFilters() const;
 
 public Q_SLOTS:
     void slotUnselectAllButton();
@@ -45,4 +44,3 @@ private:
     QPushButton *mOkButton = nullptr;
 };
 }
-#endif // FILTERSELECTIONDIALOG_H
