@@ -1,11 +1,10 @@
 /*
-  SPDX-FileCopyrightText: 2015-2021 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2015-2022 Laurent Montel <montel@kde.org>
 
   SPDX-License-Identifier: GPL-2.0-or-later
 */
 
-#ifndef INVALIDFILTERLISTMODEL_H
-#define INVALIDFILTERLISTMODEL_H
+#pragma once
 
 #include "invalidfilterinfo.h"
 #include <QAbstractListModel>
@@ -32,4 +31,3 @@ private:
 };
 }
 
-#endif // INVALIDFILTERLISTMODEL_H
