@@ -2,15 +2,14 @@
   Filter Dialog
 
   SPDX-FileCopyrightText: Marc Mutz <mutz@kde.org>
-  SPDX-FileCopyrightText: 2011-2021 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2011-2022 Laurent Montel <montel@kde.org>
 
   based upon work by Stefan Taferner <taferner@kde.org>
 
   SPDX-License-Identifier: GPL-2.0-or-later
 */
 
-#ifndef MAILCOMMON_KMFILTERDIALOG_H
-#define MAILCOMMON_KMFILTERDIALOG_H
+#pragma once
 
 #include "filterimporterexporter.h"
 #include "mailcommon/filteraction.h"
@@ -20,7 +19,6 @@
 
 #include <QDialog>
 
-#include <QGroupBox>
 #include <QList>
 
 class KActionCollection;
@@ -28,10 +26,10 @@ class KIconButton;
 class KKeySequenceWidget;
 
 class QCheckBox;
-class QLabel;
 class QPushButton;
 class QRadioButton;
 class QPushButton;
+class QGroupBox;
 namespace MailCommon
 {
 class SearchPatternEdit;
@@ -135,7 +133,6 @@ protected Q_SLOTS:
     void slotApplicabilityChanged();
     void slotApplicableAccountsChanged();
     void slotStopProcessingButtonToggled(bool aChecked);
-    void slotConfigureShortcutButtonToggled(bool aChecked);
     void slotShortcutChanged(const QKeySequence &newSeq);
     void slotConfigureToolbarButtonToggled(bool aChecked);
     void slotFilterActionIconChanged(const QString &icon);
@@ -229,7 +226,6 @@ protected:
     QCheckBox *mStopProcessingHere = nullptr;
     QCheckBox *mConfigureShortcut = nullptr;
     QCheckBox *mConfigureToolbar = nullptr;
-    QLabel *mFilterActionLabel = nullptr;
     KIconButton *mFilterActionIconButton = nullptr;
     KKeySequenceWidget *mKeySeqWidget = nullptr;
     QGroupBox *mAdvOptsGroup = nullptr;
@@ -240,7 +236,7 @@ protected:
     QPushButton *mApplyButton = nullptr;
     bool mDoNotClose = false;
     bool mIgnoreFilterUpdates = true;
+    QWidget *mInMenuWidget = nullptr;
 };
 }
 
-#endif /*kmfilterdialog_h*/
