@@ -4,8 +4,7 @@
   SPDX-License-Identifier: GPL-2.0-or-later
 */
 
-#ifndef MAILCOMMON_MDNADVICEDIALOG_H
-#define MAILCOMMON_MDNADVICEDIALOG_H
+#pragma once
 
 #include "mailcommon_export.h"
 
@@ -33,4 +32,3 @@ private:
 };
 }
 
-#endif
