@@ -5,13 +5,13 @@
   SPDX-License-Identifier: GPL-2.0-or-later
 */
 
-#ifndef MAILCOMMON_FAVORITECOLLECTIONORDERPROXYMODEL_H
-#define MAILCOMMON_FAVORITECOLLECTIONORDERPROXYMODEL_H
+#pragma once
 
 #include "mailcommon_export.h"
-#include <EntityOrderProxyModel>
+#include <Akonadi/EntityOrderProxyModel>
 
-namespace MailCommon {
+namespace MailCommon
+{
 /**
  * @brief The FavoriteCollectionOrderProxyModel class implements ordering of favorite collections.
  */
@@ -27,4 +27,3 @@ protected:
 };
 }
 
-#endif
