@@ -31,6 +31,7 @@
 
 #include <KLocalizedString>
 
+#include <QApplication>
 #include <QFontDatabase>
 #include <QHeaderView>
 #include <QKeyEvent>
@@ -126,6 +127,9 @@ FolderTreeWidget::FolderTreeWidget(QWidget *parent,
         d->filterFolderLineEdit->hide();
         setAttribute(Qt::WA_InputMethodEnabled);
     }
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
+    connect(qApp, &QApplication::paletteChanged, this, &FolderTreeWidget::slotGeneralPaletteChanged);
+#endif
 }
 
 FolderTreeWidget::~FolderTreeWidget() = default;
@@ -381,3 +385,13 @@ bool FolderTreeWidget::eventFilter(QObject *o, QEvent *e)
     }
     return false;
 }
+
+bool FolderTreeWidget::event(QEvent *e)
+{
+#if QT_VERSION >= QT_VERSION_CHECK(6, 0, 0)
+    if (e->type() == QEvent::ApplicationPaletteChange) {
+        slotGeneralPaletteChanged();
+    }
+#endif
+    return QWidget::event(e);
+}
