@@ -5,8 +5,7 @@
   SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
-#ifndef MAILCOMMON_SENDMDNHANDLER_H
-#define MAILCOMMON_SENDMDNHANDLER_H
+#pragma once
 
 #include "mailcommon_export.h"
 
@@ -14,7 +13,8 @@
 
 #include <QObject>
 
-namespace MailCommon {
+namespace MailCommon
+{
 class IKernel;
 
 /**
@@ -45,10 +45,9 @@ public:
 
 private:
     //@cond PRIVATE
-    class Private;
-    Private *const d;
+    class SendMdnHandlerPrivate;
+    std::unique_ptr<SendMdnHandlerPrivate> const d;
     //@endcond
 };
 }
 
-#endif
