@@ -1,10 +1,9 @@
 /*
-  SPDX-FileCopyrightText: 2015-2021 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2015-2022 Laurent Montel <montel@kde.org>
 
   SPDX-License-Identifier: GPL-2.0-only
 */
-#ifndef SEARCHRULESTRINGTEST_H
-#define SEARCHRULESTRINGTEST_H
+#pragma once
 
 #include <QObject>
 
@@ -23,4 +22,3 @@ private Q_SLOTS:
     void shouldBeEmpty();
 };
 
-#endif // SEARCHRULESTRINGTEST_H
