@@ -1,5 +1,5 @@
 /*
-  SPDX-FileCopyrightText: 2013-2020 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2013-2022 Laurent Montel <montel@kde.org>
 
   SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -9,28 +9,24 @@
 
 #include <KLocalizedString>
 
+#include <QComboBox>
 #include <QDoubleSpinBox>
 #include <QStackedWidget>
-#include <QComboBox>
-
+#include <KLazyLocalizedString>
 using namespace MailCommon;
 
 static const struct {
     SearchRule::Function id;
-    const char *displayName;
-} NumericFunctions[] = {
-    { SearchRule::FuncEquals, I18N_NOOP("is equal to")         },
-    { SearchRule::FuncNotEqual, I18N_NOOP("is not equal to")      },
-    { SearchRule::FuncIsGreater, I18N_NOOP("is greater than")     },
-    { SearchRule::FuncIsLessOrEqual, I18N_NOOP("is less than or equal to") },
-    { SearchRule::FuncIsLess, I18N_NOOP("is less than")        },
-    { SearchRule::FuncIsGreaterOrEqual, I18N_NOOP("is greater than or equal to") }
-};
-static const int NumericFunctionCount
-    = sizeof(NumericFunctions) / sizeof(*NumericFunctions);
+    const KLazyLocalizedString displayName;
+} NumericDoubleFunctions[] = {{SearchRule::FuncEquals, kli18n("is equal to")},
+                              {SearchRule::FuncNotEqual, kli18n("is not equal to")},
+                              {SearchRule::FuncIsGreater, kli18n("is greater than")},
+                              {SearchRule::FuncIsLessOrEqual, kli18n("is less than or equal to")},
+                              {SearchRule::FuncIsLess, kli18n("is less than")},
+                              {SearchRule::FuncIsGreaterOrEqual, kli18n("is greater than or equal to")}};
+static const int NumericDoubleFunctionCount = sizeof(NumericDoubleFunctions) / sizeof(*NumericDoubleFunctions);
 
-QWidget *NumericDoubleRuleWidgetHandler::createFunctionWidget(
-    int number, QStackedWidget *functionStack, const QObject *receiver, bool /*isBalooSearch*/) const
+QWidget *NumericDoubleRuleWidgetHandler::createFunctionWidget(int number, QStackedWidget *functionStack, const QObject *receiver, bool /*isBalooSearch*/) const
 {
     if (number != 0) {
         return nullptr;
@@ -39,12 +35,11 @@ QWidget *NumericDoubleRuleWidgetHandler::createFunctionWidget(
     auto funcCombo = new QComboBox(functionStack);
     funcCombo->setMinimumWidth(50);
     funcCombo->setObjectName(QStringLiteral("numericDoubleRuleFuncCombo"));
-    for (int i = 0; i < NumericFunctionCount; ++i) {
-        funcCombo->addItem(i18n(NumericFunctions[i].displayName));
+    for (int i = 0; i < NumericDoubleFunctionCount; ++i) {
+        funcCombo->addItem(NumericDoubleFunctions[i].displayName.toString());
     }
     funcCombo->adjustSize();
-    QObject::connect(funcCombo, SIGNAL(activated(int)),
-                     receiver, SLOT(slotFunctionChanged()));
+    QObject::connect(funcCombo, SIGNAL(activated(int)), receiver, SLOT(slotFunctionChanged()));
     return funcCombo;
 }
 
@@ -56,22 +51,20 @@ QWidget *NumericDoubleRuleWidgetHandler::createValueWidget(int number, QStackedW
         return nullptr;
     }
 
-    auto *numInput = new QDoubleSpinBox(valueStack);
+    auto numInput = new QDoubleSpinBox(valueStack);
     numInput->setObjectName(QStringLiteral("QDoubleSpinBox"));
-    QObject::connect(numInput, SIGNAL(valueChanged(double)),
-                     receiver, SLOT(slotValueChanged()));
+    QObject::connect(numInput, SIGNAL(valueChanged(double)), receiver, SLOT(slotValueChanged()));
     return numInput;
 }
 
 //---------------------------------------------------------------------------
 
-SearchRule::Function NumericDoubleRuleWidgetHandler::currentFunction(
-    const QStackedWidget *functionStack) const
+SearchRule::Function NumericDoubleRuleWidgetHandler::currentFunction(const QStackedWidget *functionStack) const
 {
     const auto funcCombo = functionStack->findChild<QComboBox *>(QStringLiteral("numericDoubleRuleFuncCombo"));
 
     if (funcCombo && funcCombo->currentIndex() >= 0) {
-        return NumericFunctions[funcCombo->currentIndex()].id;
+        return NumericDoubleFunctions[funcCombo->currentIndex()].id;
     }
 
     return SearchRule::FuncNone;
@@ -98,7 +91,7 @@ QString NumericDoubleRuleWidgetHandler::currentValue(const QStackedWidget *value
         return QString::number(int(numInput->value() * 1024));
     }
 
-    return QString();
+    return {};
 }
 
 //---------------------------------------------------------------------------
@@ -106,7 +99,7 @@ QString NumericDoubleRuleWidgetHandler::currentValue(const QStackedWidget *value
 QString NumericDoubleRuleWidgetHandler::value(const QByteArray &field, const QStackedWidget *, const QStackedWidget *valueStack) const
 {
     if (!handlesField(field)) {
-        return QString();
+        return {};
     }
 
     return currentValue(valueStack);
@@ -117,7 +110,7 @@ QString NumericDoubleRuleWidgetHandler::value(const QByteArray &field, const QSt
 QString NumericDoubleRuleWidgetHandler::prettyValue(const QByteArray &field, const QStackedWidget *, const QStackedWidget *valueStack) const
 {
     if (!handlesField(field)) {
-        return QString();
+        return {};
     }
 
     return currentValue(valueStack);
@@ -167,7 +160,10 @@ void initDoubleNumInput(QDoubleSpinBox *numInput, const QByteArray &field)
 
 //---------------------------------------------------------------------------
 
-bool NumericDoubleRuleWidgetHandler::setRule(QStackedWidget *functionStack, QStackedWidget *valueStack, const SearchRule::Ptr rule, bool /*isBalooSearch*/) const
+bool NumericDoubleRuleWidgetHandler::setRule(QStackedWidget *functionStack,
+                                             QStackedWidget *valueStack,
+                                             const SearchRule::Ptr rule,
+                                             bool /*isBalooSearch*/) const
 {
     if (!rule || !handlesField(rule->field())) {
         reset(functionStack, valueStack);
@@ -177,8 +173,8 @@ bool NumericDoubleRuleWidgetHandler::setRule(QStackedWidget *functionStack, QSta
     // set the function
     const SearchRule::Function func = rule->function();
     int funcIndex = 0;
-    for (; funcIndex < NumericFunctionCount; ++funcIndex) {
-        if (func == NumericFunctions[funcIndex].id) {
+    for (; funcIndex < NumericDoubleFunctionCount; ++funcIndex) {
+        if (func == NumericDoubleFunctions[funcIndex].id) {
             break;
         }
     }
@@ -187,7 +183,7 @@ bool NumericDoubleRuleWidgetHandler::setRule(QStackedWidget *functionStack, QSta
 
     if (funcCombo) {
         funcCombo->blockSignals(true);
-        if (funcIndex < NumericFunctionCount) {
+        if (funcIndex < NumericDoubleFunctionCount) {
             funcCombo->setCurrentIndex(funcIndex);
         } else {
             funcCombo->setCurrentIndex(0);
