@@ -1,11 +1,10 @@
 /*
-  SPDX-FileCopyrightText: 2013-2021 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2013-2022 Laurent Montel <montel@kde.org>
 
   SPDX-License-Identifier: GPL-2.0-or-later
 */
 
-#ifndef TAGRULEWIDGETHANDLER_H
-#define TAGRULEWIDGETHANDLER_H
+#pragma once
 
 #include "interfaces/rulewidgethandler.h"
 
@@ -19,9 +18,7 @@ public:
     {
     }
 
-    ~TagRuleWidgetHandler() override
-    {
-    }
+    ~TagRuleWidgetHandler() override = default;
 
     QWidget *createFunctionWidget(int number, QStackedWidget *functionStack, const QObject *receiver, bool isBalooSearch) const override;
 
@@ -43,4 +40,3 @@ public:
 };
 }
 
-#endif // TAGRULEWIDGETHANDLER_H
