@@ -1,11 +1,10 @@
 /*
-   SPDX-FileCopyrightText: 2019-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2019-2022 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
-#ifndef SNIPPETCUSTOMFILEATTACHMENTNAMEWIDGETTEST_H
-#define SNIPPETCUSTOMFILEATTACHMENTNAMEWIDGETTEST_H
+#pragma once
 
 #include <QObject>
 
@@ -14,9 +13,8 @@ class SnippetCustomFileAttachmentNameWidgetTest : public QObject
     Q_OBJECT
 public:
     explicit SnippetCustomFileAttachmentNameWidgetTest(QObject *parent = nullptr);
-    ~SnippetCustomFileAttachmentNameWidgetTest() = default;
+    ~SnippetCustomFileAttachmentNameWidgetTest() override = default;
 private Q_SLOTS:
     void shouldHaveDefaultValues();
 };
 
-#endif // SNIPPETCUSTOMFILEATTACHMENTNAMEWIDGETTEST_H
