@@ -2,13 +2,12 @@
   SPDX-FileCopyrightText: 2010 Klarälvdalens Datakonsult AB, a KDAB Group company <info@kdab.net>
   SPDX-FileContributor: Tobias Koenig <tokoe@kdab.com>
 
-  SPDX-FileCopyrightText: 2019-2021 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2019-2022 Laurent Montel <montel@kde.org>
 
   SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
-#ifndef MAILCOMMON_SNIPPETVARIABLEDIALOG_P_H
-#define MAILCOMMON_SNIPPETVARIABLEDIALOG_P_H
+#pragma once
 
 #include <QDialog>
 
@@ -41,4 +40,3 @@ private:
 };
 }
 
-#endif
