@@ -1,12 +1,11 @@
 /*  -*- mode: C++ -*-
 
   SPDX-FileCopyrightText: 2003 Andreas Gungl <a.gungl@gmx.de>
-  SPDX-FileCopyrightText: 2014-2021 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2014-2022 Laurent Montel <montel@kde.org>
 
   SPDX-License-Identifier: GPL-2.0-only
 */
-#ifndef MAILCOMMON_REDIRECTDIALOG_H
-#define MAILCOMMON_REDIRECTDIALOG_H
+#pragma once
 
 #include "mailcommon_export.h"
 
@@ -68,10 +67,9 @@ protected:
 
 private:
     //@cond PRIVATE
-    class Private;
-    Private *const d;
+    class RedirectDialogPrivate;
+    std::unique_ptr<RedirectDialogPrivate> const d;
     //@endcond
 };
 }
 
-#endif
